attrs: Attributes without boilerplate.
=============================================

Release v\ |release| (:doc:`What's new? <changelog>`).


.. include:: ../README.rst
   :start-after: teaser-begin


User's Guide
------------

.. toctree::
   :maxdepth: 1

   why
   examples
   api
   extending


Project Information
-------------------

.. toctree::
   :maxdepth: 1

   backward-compatibility
   license
   contributing
   changelog



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
